# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBackupDetails(object):
    """
    Complete information for a Backup.
    """

    #: A constant which can be used with the backup_type property of a CreateBackupDetails.
    #: This constant has a value of "FULL"
    BACKUP_TYPE_FULL = "FULL"

    #: A constant which can be used with the backup_type property of a CreateBackupDetails.
    #: This constant has a value of "INCREMENTAL"
    BACKUP_TYPE_INCREMENTAL = "INCREMENTAL"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBackupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateBackupDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateBackupDetails.
        :type description: str

        :param backup_type:
            The value to assign to the backup_type property of this CreateBackupDetails.
            Allowed values for this property are: "FULL", "INCREMENTAL"
        :type backup_type: str

        :param db_system_id:
            The value to assign to the db_system_id property of this CreateBackupDetails.
        :type db_system_id: str

        :param retention_in_days:
            The value to assign to the retention_in_days property of this CreateBackupDetails.
        :type retention_in_days: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateBackupDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateBackupDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'backup_type': 'str',
            'db_system_id': 'str',
            'retention_in_days': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'backup_type': 'backupType',
            'db_system_id': 'dbSystemId',
            'retention_in_days': 'retentionInDays',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._backup_type = None
        self._db_system_id = None
        self._retention_in_days = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateBackupDetails.
        A user-supplied display name for the backup.


        :return: The display_name of this CreateBackupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBackupDetails.
        A user-supplied display name for the backup.


        :param display_name: The display_name of this CreateBackupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateBackupDetails.
        A user-supplied description for the backup.


        :return: The description of this CreateBackupDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateBackupDetails.
        A user-supplied description for the backup.


        :param description: The description of this CreateBackupDetails.
        :type: str
        """
        self._description = description

    @property
    def backup_type(self):
        """
        Gets the backup_type of this CreateBackupDetails.
        The type of backup.

        Allowed values for this property are: "FULL", "INCREMENTAL"


        :return: The backup_type of this CreateBackupDetails.
        :rtype: str
        """
        return self._backup_type

    @backup_type.setter
    def backup_type(self, backup_type):
        """
        Sets the backup_type of this CreateBackupDetails.
        The type of backup.


        :param backup_type: The backup_type of this CreateBackupDetails.
        :type: str
        """
        allowed_values = ["FULL", "INCREMENTAL"]
        if not value_allowed_none_or_none_sentinel(backup_type, allowed_values):
            raise ValueError(
                "Invalid value for `backup_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._backup_type = backup_type

    @property
    def db_system_id(self):
        """
        **[Required]** Gets the db_system_id of this CreateBackupDetails.
        The OCID of the DB System the Backup is associated with.


        :return: The db_system_id of this CreateBackupDetails.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this CreateBackupDetails.
        The OCID of the DB System the Backup is associated with.


        :param db_system_id: The db_system_id of this CreateBackupDetails.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def retention_in_days(self):
        """
        Gets the retention_in_days of this CreateBackupDetails.
        Number of days to retain this backup.


        :return: The retention_in_days of this CreateBackupDetails.
        :rtype: int
        """
        return self._retention_in_days

    @retention_in_days.setter
    def retention_in_days(self, retention_in_days):
        """
        Sets the retention_in_days of this CreateBackupDetails.
        Number of days to retain this backup.


        :param retention_in_days: The retention_in_days of this CreateBackupDetails.
        :type: int
        """
        self._retention_in_days = retention_in_days

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateBackupDetails.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateBackupDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateBackupDetails.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateBackupDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateBackupDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateBackupDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateBackupDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateBackupDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .authorization_details import AuthorizationDetails
from .change_compartment_details import ChangeCompartmentDetails
from .configuration_field import ConfigurationField
from .create_migration_details import CreateMigrationDetails
from .create_source_details import CreateSourceDetails
from .discovery_details import DiscoveryDetails
from .ics_discovery_details import IcsDiscoveryDetails
from .internal_authorization_details import InternalAuthorizationDetails
from .internal_source_details import InternalSourceDetails
from .jcs_discovery_details import JcsDiscoveryDetails
from .migration import Migration
from .migration_summary import MigrationSummary
from .oac_discovery_details import OacDiscoveryDetails
from .ocic_authorization_details import OcicAuthorizationDetails
from .ocic_source_details import OcicSourceDetails
from .oic_discovery_details import OicDiscoveryDetails
from .pcs_discovery_details import PcsDiscoveryDetails
from .soacs_discovery_details import SoacsDiscoveryDetails
from .source import Source
from .source_application import SourceApplication
from .source_application_summary import SourceApplicationSummary
from .source_details import SourceDetails
from .source_summary import SourceSummary
from .update_migration_details import UpdateMigrationDetails
from .update_source_details import UpdateSourceDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for application_migration services.
application_migration_type_mapping = {
    "AuthorizationDetails": AuthorizationDetails,
    "ChangeCompartmentDetails": ChangeCompartmentDetails,
    "ConfigurationField": ConfigurationField,
    "CreateMigrationDetails": CreateMigrationDetails,
    "CreateSourceDetails": CreateSourceDetails,
    "DiscoveryDetails": DiscoveryDetails,
    "IcsDiscoveryDetails": IcsDiscoveryDetails,
    "InternalAuthorizationDetails": InternalAuthorizationDetails,
    "InternalSourceDetails": InternalSourceDetails,
    "JcsDiscoveryDetails": JcsDiscoveryDetails,
    "Migration": Migration,
    "MigrationSummary": MigrationSummary,
    "OacDiscoveryDetails": OacDiscoveryDetails,
    "OcicAuthorizationDetails": OcicAuthorizationDetails,
    "OcicSourceDetails": OcicSourceDetails,
    "OicDiscoveryDetails": OicDiscoveryDetails,
    "PcsDiscoveryDetails": PcsDiscoveryDetails,
    "SoacsDiscoveryDetails": SoacsDiscoveryDetails,
    "Source": Source,
    "SourceApplication": SourceApplication,
    "SourceApplicationSummary": SourceApplicationSummary,
    "SourceDetails": SourceDetails,
    "SourceSummary": SourceSummary,
    "UpdateMigrationDetails": UpdateMigrationDetails,
    "UpdateSourceDetails": UpdateSourceDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeleteRowResult(object):
    """
    The result of a DeleteRow operation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeleteRowResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_success:
            The value to assign to the is_success property of this DeleteRowResult.
        :type is_success: bool

        :param existing_version:
            The value to assign to the existing_version property of this DeleteRowResult.
        :type existing_version: str

        :param existing_value:
            The value to assign to the existing_value property of this DeleteRowResult.
        :type existing_value: dict(str, object)

        :param usage:
            The value to assign to the usage property of this DeleteRowResult.
        :type usage: RequestUsage

        """
        self.swagger_types = {
            'is_success': 'bool',
            'existing_version': 'str',
            'existing_value': 'dict(str, object)',
            'usage': 'RequestUsage'
        }

        self.attribute_map = {
            'is_success': 'isSuccess',
            'existing_version': 'existingVersion',
            'existing_value': 'existingValue',
            'usage': 'usage'
        }

        self._is_success = None
        self._existing_version = None
        self._existing_value = None
        self._usage = None

    @property
    def is_success(self):
        """
        Gets the is_success of this DeleteRowResult.
        Convey the success or failure of the operation.


        :return: The is_success of this DeleteRowResult.
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """
        Sets the is_success of this DeleteRowResult.
        Convey the success or failure of the operation.


        :param is_success: The is_success of this DeleteRowResult.
        :type: bool
        """
        self._is_success = is_success

    @property
    def existing_version(self):
        """
        Gets the existing_version of this DeleteRowResult.
        The version string associated with the existing row.
        Returned if the delete fails due to options setting in the
        request.


        :return: The existing_version of this DeleteRowResult.
        :rtype: str
        """
        return self._existing_version

    @existing_version.setter
    def existing_version(self, existing_version):
        """
        Sets the existing_version of this DeleteRowResult.
        The version string associated with the existing row.
        Returned if the delete fails due to options setting in the
        request.


        :param existing_version: The existing_version of this DeleteRowResult.
        :type: str
        """
        self._existing_version = existing_version

    @property
    def existing_value(self):
        """
        Gets the existing_value of this DeleteRowResult.
        The map of values from a row.


        :return: The existing_value of this DeleteRowResult.
        :rtype: dict(str, object)
        """
        return self._existing_value

    @existing_value.setter
    def existing_value(self, existing_value):
        """
        Sets the existing_value of this DeleteRowResult.
        The map of values from a row.


        :param existing_value: The existing_value of this DeleteRowResult.
        :type: dict(str, object)
        """
        self._existing_value = existing_value

    @property
    def usage(self):
        """
        Gets the usage of this DeleteRowResult.

        :return: The usage of this DeleteRowResult.
        :rtype: RequestUsage
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """
        Sets the usage of this DeleteRowResult.

        :param usage: The usage of this DeleteRowResult.
        :type: RequestUsage
        """
        self._usage = usage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AppCatalogListingResourceVersion(object):
    """
    Listing Resource Version
    """

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "SNAPSHOT"
    ALLOWED_ACTIONS_SNAPSHOT = "SNAPSHOT"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "BOOT_VOLUME_DETACH"
    ALLOWED_ACTIONS_BOOT_VOLUME_DETACH = "BOOT_VOLUME_DETACH"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "PRESERVE_BOOT_VOLUME"
    ALLOWED_ACTIONS_PRESERVE_BOOT_VOLUME = "PRESERVE_BOOT_VOLUME"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "SERIAL_CONSOLE_ACCESS"
    ALLOWED_ACTIONS_SERIAL_CONSOLE_ACCESS = "SERIAL_CONSOLE_ACCESS"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "BOOT_RECOVERY"
    ALLOWED_ACTIONS_BOOT_RECOVERY = "BOOT_RECOVERY"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "BACKUP_BOOT_VOLUME"
    ALLOWED_ACTIONS_BACKUP_BOOT_VOLUME = "BACKUP_BOOT_VOLUME"

    #: A constant which can be used with the allowed_actions property of a AppCatalogListingResourceVersion.
    #: This constant has a value of "CAPTURE_CONSOLE_HISTORY"
    ALLOWED_ACTIONS_CAPTURE_CONSOLE_HISTORY = "CAPTURE_CONSOLE_HISTORY"

    def __init__(self, **kwargs):
        """
        Initializes a new AppCatalogListingResourceVersion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param listing_id:
            The value to assign to the listing_id property of this AppCatalogListingResourceVersion.
        :type listing_id: str

        :param time_published:
            The value to assign to the time_published property of this AppCatalogListingResourceVersion.
        :type time_published: datetime

        :param listing_resource_id:
            The value to assign to the listing_resource_id property of this AppCatalogListingResourceVersion.
        :type listing_resource_id: str

        :param listing_resource_version:
            The value to assign to the listing_resource_version property of this AppCatalogListingResourceVersion.
        :type listing_resource_version: str

        :param available_regions:
            The value to assign to the available_regions property of this AppCatalogListingResourceVersion.
        :type available_regions: list[str]

        :param compatible_shapes:
            The value to assign to the compatible_shapes property of this AppCatalogListingResourceVersion.
        :type compatible_shapes: list[str]

        :param accessible_ports:
            The value to assign to the accessible_ports property of this AppCatalogListingResourceVersion.
        :type accessible_ports: list[int]

        :param allowed_actions:
            The value to assign to the allowed_actions property of this AppCatalogListingResourceVersion.
            Allowed values for items in this list are: "SNAPSHOT", "BOOT_VOLUME_DETACH", "PRESERVE_BOOT_VOLUME", "SERIAL_CONSOLE_ACCESS", "BOOT_RECOVERY", "BACKUP_BOOT_VOLUME", "CAPTURE_CONSOLE_HISTORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type allowed_actions: list[str]

        """
        self.swagger_types = {
            'listing_id': 'str',
            'time_published': 'datetime',
            'listing_resource_id': 'str',
            'listing_resource_version': 'str',
            'available_regions': 'list[str]',
            'compatible_shapes': 'list[str]',
            'accessible_ports': 'list[int]',
            'allowed_actions': 'list[str]'
        }

        self.attribute_map = {
            'listing_id': 'listingId',
            'time_published': 'timePublished',
            'listing_resource_id': 'listingResourceId',
            'listing_resource_version': 'listingResourceVersion',
            'available_regions': 'availableRegions',
            'compatible_shapes': 'compatibleShapes',
            'accessible_ports': 'accessiblePorts',
            'allowed_actions': 'allowedActions'
        }

        self._listing_id = None
        self._time_published = None
        self._listing_resource_id = None
        self._listing_resource_version = None
        self._available_regions = None
        self._compatible_shapes = None
        self._accessible_ports = None
        self._allowed_actions = None

    @property
    def listing_id(self):
        """
        Gets the listing_id of this AppCatalogListingResourceVersion.
        The OCID of the listing this resource version belongs to.


        :return: The listing_id of this AppCatalogListingResourceVersion.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this AppCatalogListingResourceVersion.
        The OCID of the listing this resource version belongs to.


        :param listing_id: The listing_id of this AppCatalogListingResourceVersion.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def time_published(self):
        """
        Gets the time_published of this AppCatalogListingResourceVersion.
        Date and time the listing resource version was published, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_published of this AppCatalogListingResourceVersion.
        :rtype: datetime
        """
        return self._time_published

    @time_published.setter
    def time_published(self, time_published):
        """
        Sets the time_published of this AppCatalogListingResourceVersion.
        Date and time the listing resource version was published, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_published: The time_published of this AppCatalogListingResourceVersion.
        :type: datetime
        """
        self._time_published = time_published

    @property
    def listing_resource_id(self):
        """
        Gets the listing_resource_id of this AppCatalogListingResourceVersion.
        OCID of the listing resource.


        :return: The listing_resource_id of this AppCatalogListingResourceVersion.
        :rtype: str
        """
        return self._listing_resource_id

    @listing_resource_id.setter
    def listing_resource_id(self, listing_resource_id):
        """
        Sets the listing_resource_id of this AppCatalogListingResourceVersion.
        OCID of the listing resource.


        :param listing_resource_id: The listing_resource_id of this AppCatalogListingResourceVersion.
        :type: str
        """
        self._listing_resource_id = listing_resource_id

    @property
    def listing_resource_version(self):
        """
        Gets the listing_resource_version of this AppCatalogListingResourceVersion.
        Resource Version.


        :return: The listing_resource_version of this AppCatalogListingResourceVersion.
        :rtype: str
        """
        return self._listing_resource_version

    @listing_resource_version.setter
    def listing_resource_version(self, listing_resource_version):
        """
        Sets the listing_resource_version of this AppCatalogListingResourceVersion.
        Resource Version.


        :param listing_resource_version: The listing_resource_version of this AppCatalogListingResourceVersion.
        :type: str
        """
        self._listing_resource_version = listing_resource_version

    @property
    def available_regions(self):
        """
        Gets the available_regions of this AppCatalogListingResourceVersion.
        List of regions that this listing resource version is available.

        For information about Regions, see
        `Regions`__.

        Example: `[\"us-ashburn-1\", \"us-phoenix-1\"]`

        __ https://docs.cloud.oracle.com/#General/Concepts/regions.htm


        :return: The available_regions of this AppCatalogListingResourceVersion.
        :rtype: list[str]
        """
        return self._available_regions

    @available_regions.setter
    def available_regions(self, available_regions):
        """
        Sets the available_regions of this AppCatalogListingResourceVersion.
        List of regions that this listing resource version is available.

        For information about Regions, see
        `Regions`__.

        Example: `[\"us-ashburn-1\", \"us-phoenix-1\"]`

        __ https://docs.cloud.oracle.com/#General/Concepts/regions.htm


        :param available_regions: The available_regions of this AppCatalogListingResourceVersion.
        :type: list[str]
        """
        self._available_regions = available_regions

    @property
    def compatible_shapes(self):
        """
        Gets the compatible_shapes of this AppCatalogListingResourceVersion.
        Array of shapes compatible with this resource.

        You may enumerate all available shapes by calling :func:`list_shapes`.

        Example: `[\"VM.Standard1.1\", \"VM.Standard1.2\"]`


        :return: The compatible_shapes of this AppCatalogListingResourceVersion.
        :rtype: list[str]
        """
        return self._compatible_shapes

    @compatible_shapes.setter
    def compatible_shapes(self, compatible_shapes):
        """
        Sets the compatible_shapes of this AppCatalogListingResourceVersion.
        Array of shapes compatible with this resource.

        You may enumerate all available shapes by calling :func:`list_shapes`.

        Example: `[\"VM.Standard1.1\", \"VM.Standard1.2\"]`


        :param compatible_shapes: The compatible_shapes of this AppCatalogListingResourceVersion.
        :type: list[str]
        """
        self._compatible_shapes = compatible_shapes

    @property
    def accessible_ports(self):
        """
        Gets the accessible_ports of this AppCatalogListingResourceVersion.
        List of accessible ports for instances launched with this listing resource version.


        :return: The accessible_ports of this AppCatalogListingResourceVersion.
        :rtype: list[int]
        """
        return self._accessible_ports

    @accessible_ports.setter
    def accessible_ports(self, accessible_ports):
        """
        Sets the accessible_ports of this AppCatalogListingResourceVersion.
        List of accessible ports for instances launched with this listing resource version.


        :param accessible_ports: The accessible_ports of this AppCatalogListingResourceVersion.
        :type: list[int]
        """
        self._accessible_ports = accessible_ports

    @property
    def allowed_actions(self):
        """
        Gets the allowed_actions of this AppCatalogListingResourceVersion.
        Allowed actions for the listing resource.

        Allowed values for items in this list are: "SNAPSHOT", "BOOT_VOLUME_DETACH", "PRESERVE_BOOT_VOLUME", "SERIAL_CONSOLE_ACCESS", "BOOT_RECOVERY", "BACKUP_BOOT_VOLUME", "CAPTURE_CONSOLE_HISTORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The allowed_actions of this AppCatalogListingResourceVersion.
        :rtype: list[str]
        """
        return self._allowed_actions

    @allowed_actions.setter
    def allowed_actions(self, allowed_actions):
        """
        Sets the allowed_actions of this AppCatalogListingResourceVersion.
        Allowed actions for the listing resource.


        :param allowed_actions: The allowed_actions of this AppCatalogListingResourceVersion.
        :type: list[str]
        """
        allowed_values = ["SNAPSHOT", "BOOT_VOLUME_DETACH", "PRESERVE_BOOT_VOLUME", "SERIAL_CONSOLE_ACCESS", "BOOT_RECOVERY", "BACKUP_BOOT_VOLUME", "CAPTURE_CONSOLE_HISTORY"]
        if allowed_actions:
            allowed_actions[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in allowed_actions]
        self._allowed_actions = allowed_actions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OceInstance(object):
    """
    Details of OceInstance.
    """

    #: A constant which can be used with the upgrade_schedule property of a OceInstance.
    #: This constant has a value of "UPGRADE_IMMEDIATELY"
    UPGRADE_SCHEDULE_UPGRADE_IMMEDIATELY = "UPGRADE_IMMEDIATELY"

    #: A constant which can be used with the upgrade_schedule property of a OceInstance.
    #: This constant has a value of "DELAYED_UPGRADE"
    UPGRADE_SCHEDULE_DELAYED_UPGRADE = "DELAYED_UPGRADE"

    #: A constant which can be used with the instance_usage_type property of a OceInstance.
    #: This constant has a value of "PRIMARY"
    INSTANCE_USAGE_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the instance_usage_type property of a OceInstance.
    #: This constant has a value of "NONPRIMARY"
    INSTANCE_USAGE_TYPE_NONPRIMARY = "NONPRIMARY"

    #: A constant which can be used with the instance_access_type property of a OceInstance.
    #: This constant has a value of "PUBLIC"
    INSTANCE_ACCESS_TYPE_PUBLIC = "PUBLIC"

    #: A constant which can be used with the instance_access_type property of a OceInstance.
    #: This constant has a value of "PRIVATE"
    INSTANCE_ACCESS_TYPE_PRIVATE = "PRIVATE"

    #: A constant which can be used with the instance_license_type property of a OceInstance.
    #: This constant has a value of "NEW"
    INSTANCE_LICENSE_TYPE_NEW = "NEW"

    #: A constant which can be used with the instance_license_type property of a OceInstance.
    #: This constant has a value of "BYOL"
    INSTANCE_LICENSE_TYPE_BYOL = "BYOL"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a OceInstance.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new OceInstance object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OceInstance.
        :type id: str

        :param guid:
            The value to assign to the guid property of this OceInstance.
        :type guid: str

        :param description:
            The value to assign to the description property of this OceInstance.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OceInstance.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this OceInstance.
        :type name: str

        :param tenancy_id:
            The value to assign to the tenancy_id property of this OceInstance.
        :type tenancy_id: str

        :param idcs_tenancy:
            The value to assign to the idcs_tenancy property of this OceInstance.
        :type idcs_tenancy: str

        :param tenancy_name:
            The value to assign to the tenancy_name property of this OceInstance.
        :type tenancy_name: str

        :param upgrade_schedule:
            The value to assign to the upgrade_schedule property of this OceInstance.
            Allowed values for this property are: "UPGRADE_IMMEDIATELY", "DELAYED_UPGRADE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type upgrade_schedule: str

        :param identity_stripe:
            The value to assign to the identity_stripe property of this OceInstance.
        :type identity_stripe: IdentityStripeDetails

        :param instance_usage_type:
            The value to assign to the instance_usage_type property of this OceInstance.
            Allowed values for this property are: "PRIMARY", "NONPRIMARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_usage_type: str

        :param object_storage_namespace:
            The value to assign to the object_storage_namespace property of this OceInstance.
        :type object_storage_namespace: str

        :param admin_email:
            The value to assign to the admin_email property of this OceInstance.
        :type admin_email: str

        :param waf_primary_domain:
            The value to assign to the waf_primary_domain property of this OceInstance.
        :type waf_primary_domain: str

        :param instance_access_type:
            The value to assign to the instance_access_type property of this OceInstance.
            Allowed values for this property are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_access_type: str

        :param instance_license_type:
            The value to assign to the instance_license_type property of this OceInstance.
            Allowed values for this property are: "NEW", "BYOL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_license_type: str

        :param time_created:
            The value to assign to the time_created property of this OceInstance.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this OceInstance.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OceInstance.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param state_message:
            The value to assign to the state_message property of this OceInstance.
        :type state_message: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OceInstance.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OceInstance.
        :type defined_tags: dict(str, dict(str, object))

        :param service:
            The value to assign to the service property of this OceInstance.
        :type service: dict(str, object)

        """
        self.swagger_types = {
            'id': 'str',
            'guid': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'tenancy_id': 'str',
            'idcs_tenancy': 'str',
            'tenancy_name': 'str',
            'upgrade_schedule': 'str',
            'identity_stripe': 'IdentityStripeDetails',
            'instance_usage_type': 'str',
            'object_storage_namespace': 'str',
            'admin_email': 'str',
            'waf_primary_domain': 'str',
            'instance_access_type': 'str',
            'instance_license_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'state_message': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'service': 'dict(str, object)'
        }

        self.attribute_map = {
            'id': 'id',
            'guid': 'guid',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'tenancy_id': 'tenancyId',
            'idcs_tenancy': 'idcsTenancy',
            'tenancy_name': 'tenancyName',
            'upgrade_schedule': 'upgradeSchedule',
            'identity_stripe': 'identityStripe',
            'instance_usage_type': 'instanceUsageType',
            'object_storage_namespace': 'objectStorageNamespace',
            'admin_email': 'adminEmail',
            'waf_primary_domain': 'wafPrimaryDomain',
            'instance_access_type': 'instanceAccessType',
            'instance_license_type': 'instanceLicenseType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'state_message': 'stateMessage',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'service': 'service'
        }

        self._id = None
        self._guid = None
        self._description = None
        self._compartment_id = None
        self._name = None
        self._tenancy_id = None
        self._idcs_tenancy = None
        self._tenancy_name = None
        self._upgrade_schedule = None
        self._identity_stripe = None
        self._instance_usage_type = None
        self._object_storage_namespace = None
        self._admin_email = None
        self._waf_primary_domain = None
        self._instance_access_type = None
        self._instance_license_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._state_message = None
        self._freeform_tags = None
        self._defined_tags = None
        self._service = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OceInstance.
        Unique identifier that is immutable on creation


        :return: The id of this OceInstance.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OceInstance.
        Unique identifier that is immutable on creation


        :param id: The id of this OceInstance.
        :type: str
        """
        self._id = id

    @property
    def guid(self):
        """
        **[Required]** Gets the guid of this OceInstance.
        Unique GUID identifier that is immutable on creation


        :return: The guid of this OceInstance.
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """
        Sets the guid of this OceInstance.
        Unique GUID identifier that is immutable on creation


        :param guid: The guid of this OceInstance.
        :type: str
        """
        self._guid = guid

    @property
    def description(self):
        """
        Gets the description of this OceInstance.
        OceInstance description, can be updated


        :return: The description of this OceInstance.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OceInstance.
        OceInstance description, can be updated


        :param description: The description of this OceInstance.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this OceInstance.
        Compartment Identifier


        :return: The compartment_id of this OceInstance.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this OceInstance.
        Compartment Identifier


        :param compartment_id: The compartment_id of this OceInstance.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OceInstance.
        OceInstance Name


        :return: The name of this OceInstance.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OceInstance.
        OceInstance Name


        :param name: The name of this OceInstance.
        :type: str
        """
        self._name = name

    @property
    def tenancy_id(self):
        """
        **[Required]** Gets the tenancy_id of this OceInstance.
        Tenancy Identifier


        :return: The tenancy_id of this OceInstance.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this OceInstance.
        Tenancy Identifier


        :param tenancy_id: The tenancy_id of this OceInstance.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def idcs_tenancy(self):
        """
        **[Required]** Gets the idcs_tenancy of this OceInstance.
        IDCS Tenancy Identifier


        :return: The idcs_tenancy of this OceInstance.
        :rtype: str
        """
        return self._idcs_tenancy

    @idcs_tenancy.setter
    def idcs_tenancy(self, idcs_tenancy):
        """
        Sets the idcs_tenancy of this OceInstance.
        IDCS Tenancy Identifier


        :param idcs_tenancy: The idcs_tenancy of this OceInstance.
        :type: str
        """
        self._idcs_tenancy = idcs_tenancy

    @property
    def tenancy_name(self):
        """
        **[Required]** Gets the tenancy_name of this OceInstance.
        Tenancy Name


        :return: The tenancy_name of this OceInstance.
        :rtype: str
        """
        return self._tenancy_name

    @tenancy_name.setter
    def tenancy_name(self, tenancy_name):
        """
        Sets the tenancy_name of this OceInstance.
        Tenancy Name


        :param tenancy_name: The tenancy_name of this OceInstance.
        :type: str
        """
        self._tenancy_name = tenancy_name

    @property
    def upgrade_schedule(self):
        """
        Gets the upgrade_schedule of this OceInstance.
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released
        or delay upgrade of the service to previous released version

        Allowed values for this property are: "UPGRADE_IMMEDIATELY", "DELAYED_UPGRADE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The upgrade_schedule of this OceInstance.
        :rtype: str
        """
        return self._upgrade_schedule

    @upgrade_schedule.setter
    def upgrade_schedule(self, upgrade_schedule):
        """
        Sets the upgrade_schedule of this OceInstance.
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released
        or delay upgrade of the service to previous released version


        :param upgrade_schedule: The upgrade_schedule of this OceInstance.
        :type: str
        """
        allowed_values = ["UPGRADE_IMMEDIATELY", "DELAYED_UPGRADE"]
        if not value_allowed_none_or_none_sentinel(upgrade_schedule, allowed_values):
            upgrade_schedule = 'UNKNOWN_ENUM_VALUE'
        self._upgrade_schedule = upgrade_schedule

    @property
    def identity_stripe(self):
        """
        Gets the identity_stripe of this OceInstance.

        :return: The identity_stripe of this OceInstance.
        :rtype: IdentityStripeDetails
        """
        return self._identity_stripe

    @identity_stripe.setter
    def identity_stripe(self, identity_stripe):
        """
        Sets the identity_stripe of this OceInstance.

        :param identity_stripe: The identity_stripe of this OceInstance.
        :type: IdentityStripeDetails
        """
        self._identity_stripe = identity_stripe

    @property
    def instance_usage_type(self):
        """
        Gets the instance_usage_type of this OceInstance.
        Instance type based on its usage

        Allowed values for this property are: "PRIMARY", "NONPRIMARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_usage_type of this OceInstance.
        :rtype: str
        """
        return self._instance_usage_type

    @instance_usage_type.setter
    def instance_usage_type(self, instance_usage_type):
        """
        Sets the instance_usage_type of this OceInstance.
        Instance type based on its usage


        :param instance_usage_type: The instance_usage_type of this OceInstance.
        :type: str
        """
        allowed_values = ["PRIMARY", "NONPRIMARY"]
        if not value_allowed_none_or_none_sentinel(instance_usage_type, allowed_values):
            instance_usage_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_usage_type = instance_usage_type

    @property
    def object_storage_namespace(self):
        """
        **[Required]** Gets the object_storage_namespace of this OceInstance.
        Object Storage Namespace of tenancy


        :return: The object_storage_namespace of this OceInstance.
        :rtype: str
        """
        return self._object_storage_namespace

    @object_storage_namespace.setter
    def object_storage_namespace(self, object_storage_namespace):
        """
        Sets the object_storage_namespace of this OceInstance.
        Object Storage Namespace of tenancy


        :param object_storage_namespace: The object_storage_namespace of this OceInstance.
        :type: str
        """
        self._object_storage_namespace = object_storage_namespace

    @property
    def admin_email(self):
        """
        **[Required]** Gets the admin_email of this OceInstance.
        Admin Email for Notification


        :return: The admin_email of this OceInstance.
        :rtype: str
        """
        return self._admin_email

    @admin_email.setter
    def admin_email(self, admin_email):
        """
        Sets the admin_email of this OceInstance.
        Admin Email for Notification


        :param admin_email: The admin_email of this OceInstance.
        :type: str
        """
        self._admin_email = admin_email

    @property
    def waf_primary_domain(self):
        """
        Gets the waf_primary_domain of this OceInstance.
        Web Application Firewall(WAF) primary domain


        :return: The waf_primary_domain of this OceInstance.
        :rtype: str
        """
        return self._waf_primary_domain

    @waf_primary_domain.setter
    def waf_primary_domain(self, waf_primary_domain):
        """
        Sets the waf_primary_domain of this OceInstance.
        Web Application Firewall(WAF) primary domain


        :param waf_primary_domain: The waf_primary_domain of this OceInstance.
        :type: str
        """
        self._waf_primary_domain = waf_primary_domain

    @property
    def instance_access_type(self):
        """
        Gets the instance_access_type of this OceInstance.
        Flag indicating whether the instance access is private or public

        Allowed values for this property are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_access_type of this OceInstance.
        :rtype: str
        """
        return self._instance_access_type

    @instance_access_type.setter
    def instance_access_type(self, instance_access_type):
        """
        Sets the instance_access_type of this OceInstance.
        Flag indicating whether the instance access is private or public


        :param instance_access_type: The instance_access_type of this OceInstance.
        :type: str
        """
        allowed_values = ["PUBLIC", "PRIVATE"]
        if not value_allowed_none_or_none_sentinel(instance_access_type, allowed_values):
            instance_access_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_access_type = instance_access_type

    @property
    def instance_license_type(self):
        """
        Gets the instance_license_type of this OceInstance.
        Flag indicating whether the instance license is new cloud or bring your own license

        Allowed values for this property are: "NEW", "BYOL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_license_type of this OceInstance.
        :rtype: str
        """
        return self._instance_license_type

    @instance_license_type.setter
    def instance_license_type(self, instance_license_type):
        """
        Sets the instance_license_type of this OceInstance.
        Flag indicating whether the instance license is new cloud or bring your own license


        :param instance_license_type: The instance_license_type of this OceInstance.
        :type: str
        """
        allowed_values = ["NEW", "BYOL"]
        if not value_allowed_none_or_none_sentinel(instance_license_type, allowed_values):
            instance_license_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_license_type = instance_license_type

    @property
    def time_created(self):
        """
        Gets the time_created of this OceInstance.
        The time the the OceInstance was created. An RFC3339 formatted datetime string


        :return: The time_created of this OceInstance.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this OceInstance.
        The time the the OceInstance was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this OceInstance.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this OceInstance.
        The time the OceInstance was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this OceInstance.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this OceInstance.
        The time the OceInstance was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this OceInstance.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OceInstance.
        The current state of the file system.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OceInstance.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OceInstance.
        The current state of the file system.


        :param lifecycle_state: The lifecycle_state of this OceInstance.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def state_message(self):
        """
        Gets the state_message of this OceInstance.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The state_message of this OceInstance.
        :rtype: str
        """
        return self._state_message

    @state_message.setter
    def state_message(self, state_message):
        """
        Sets the state_message of this OceInstance.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param state_message: The state_message of this OceInstance.
        :type: str
        """
        self._state_message = state_message

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this OceInstance.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this OceInstance.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this OceInstance.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this OceInstance.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this OceInstance.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this OceInstance.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this OceInstance.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this OceInstance.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def service(self):
        """
        Gets the service of this OceInstance.
        SERVICE data.
        Example: `{\"service\": {\"IDCS\": \"value\"}}`


        :return: The service of this OceInstance.
        :rtype: dict(str, object)
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this OceInstance.
        SERVICE data.
        Example: `{\"service\": {\"IDCS\": \"value\"}}`


        :param service: The service of this OceInstance.
        :type: dict(str, object)
        """
        self._service = service

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright (c) 2013-2018, Kim Davies. All rights reserved.

from .core import *
from .codec import *

def ToASCII(label):
    return encode(label)

def ToUnicode(label):
    return decode(label)

def nameprep(s):
    raise NotImplementedError("IDNA 2008 does not utilise nameprep protocol")




# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemEndpoint(object):
    """
    A particular functional endpoint for access to a DB System, and the properties that apply to it.
    """

    #: A constant which can be used with the modes property of a DbSystemEndpoint.
    #: This constant has a value of "READ"
    MODES_READ = "READ"

    #: A constant which can be used with the modes property of a DbSystemEndpoint.
    #: This constant has a value of "WRITE"
    MODES_WRITE = "WRITE"

    #: A constant which can be used with the status property of a DbSystemEndpoint.
    #: This constant has a value of "ACTIVE"
    STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the status property of a DbSystemEndpoint.
    #: This constant has a value of "INACTIVE"
    STATUS_INACTIVE = "INACTIVE"

    #: A constant which can be used with the status property of a DbSystemEndpoint.
    #: This constant has a value of "UPDATING"
    STATUS_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemEndpoint object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hostname:
            The value to assign to the hostname property of this DbSystemEndpoint.
        :type hostname: str

        :param ip_address:
            The value to assign to the ip_address property of this DbSystemEndpoint.
        :type ip_address: str

        :param port:
            The value to assign to the port property of this DbSystemEndpoint.
        :type port: int

        :param port_x:
            The value to assign to the port_x property of this DbSystemEndpoint.
        :type port_x: int

        :param modes:
            The value to assign to the modes property of this DbSystemEndpoint.
            Allowed values for items in this list are: "READ", "WRITE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type modes: list[str]

        :param status:
            The value to assign to the status property of this DbSystemEndpoint.
            Allowed values for this property are: "ACTIVE", "INACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param status_details:
            The value to assign to the status_details property of this DbSystemEndpoint.
        :type status_details: str

        """
        self.swagger_types = {
            'hostname': 'str',
            'ip_address': 'str',
            'port': 'int',
            'port_x': 'int',
            'modes': 'list[str]',
            'status': 'str',
            'status_details': 'str'
        }

        self.attribute_map = {
            'hostname': 'hostname',
            'ip_address': 'ipAddress',
            'port': 'port',
            'port_x': 'portX',
            'modes': 'modes',
            'status': 'status',
            'status_details': 'statusDetails'
        }

        self._hostname = None
        self._ip_address = None
        self._port = None
        self._port_x = None
        self._modes = None
        self._status = None
        self._status_details = None

    @property
    def hostname(self):
        """
        Gets the hostname of this DbSystemEndpoint.
        The network address of the DB System.


        :return: The hostname of this DbSystemEndpoint.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this DbSystemEndpoint.
        The network address of the DB System.


        :param hostname: The hostname of this DbSystemEndpoint.
        :type: str
        """
        self._hostname = hostname

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this DbSystemEndpoint.
        The IP address the DB System is configured to listen on.


        :return: The ip_address of this DbSystemEndpoint.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this DbSystemEndpoint.
        The IP address the DB System is configured to listen on.


        :param ip_address: The ip_address of this DbSystemEndpoint.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def port(self):
        """
        **[Required]** Gets the port of this DbSystemEndpoint.
        The port the MySQL instance listens on.


        :return: The port of this DbSystemEndpoint.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this DbSystemEndpoint.
        The port the MySQL instance listens on.


        :param port: The port of this DbSystemEndpoint.
        :type: int
        """
        self._port = port

    @property
    def port_x(self):
        """
        **[Required]** Gets the port_x of this DbSystemEndpoint.
        The network port where to connect to use this endpoint using the X protocol.


        :return: The port_x of this DbSystemEndpoint.
        :rtype: int
        """
        return self._port_x

    @port_x.setter
    def port_x(self, port_x):
        """
        Sets the port_x of this DbSystemEndpoint.
        The network port where to connect to use this endpoint using the X protocol.


        :param port_x: The port_x of this DbSystemEndpoint.
        :type: int
        """
        self._port_x = port_x

    @property
    def modes(self):
        """
        Gets the modes of this DbSystemEndpoint.
        The access modes from the client that this endpoint supports.

        Allowed values for items in this list are: "READ", "WRITE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The modes of this DbSystemEndpoint.
        :rtype: list[str]
        """
        return self._modes

    @modes.setter
    def modes(self, modes):
        """
        Sets the modes of this DbSystemEndpoint.
        The access modes from the client that this endpoint supports.


        :param modes: The modes of this DbSystemEndpoint.
        :type: list[str]
        """
        allowed_values = ["READ", "WRITE"]
        if modes:
            modes[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in modes]
        self._modes = modes

    @property
    def status(self):
        """
        Gets the status of this DbSystemEndpoint.
        The state of the endpoints, as far as it can seen from the DB System.
        There may be some inconsistency with the actual state of the MySQL service.

        Allowed values for this property are: "ACTIVE", "INACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this DbSystemEndpoint.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DbSystemEndpoint.
        The state of the endpoints, as far as it can seen from the DB System.
        There may be some inconsistency with the actual state of the MySQL service.


        :param status: The status of this DbSystemEndpoint.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def status_details(self):
        """
        Gets the status_details of this DbSystemEndpoint.
        Additional information about the current endpoint status.


        :return: The status_details of this DbSystemEndpoint.
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """
        Sets the status_details of this DbSystemEndpoint.
        Additional information about the current endpoint status.


        :param status_details: The status_details of this DbSystemEndpoint.
        :type: str
        """
        self._status_details = status_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublishResult(object):
    """
    The response to a PublishMessage call.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PublishResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param message_id:
            The value to assign to the message_id property of this PublishResult.
        :type message_id: str

        :param time_stamp:
            The value to assign to the time_stamp property of this PublishResult.
        :type time_stamp: datetime

        """
        self.swagger_types = {
            'message_id': 'str',
            'time_stamp': 'datetime'
        }

        self.attribute_map = {
            'message_id': 'messageId',
            'time_stamp': 'timeStamp'
        }

        self._message_id = None
        self._time_stamp = None

    @property
    def message_id(self):
        """
        **[Required]** Gets the message_id of this PublishResult.
        The UUID of the message.


        :return: The message_id of this PublishResult.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """
        Sets the message_id of this PublishResult.
        The UUID of the message.


        :param message_id: The message_id of this PublishResult.
        :type: str
        """
        self._message_id = message_id

    @property
    def time_stamp(self):
        """
        Gets the time_stamp of this PublishResult.
        The time that the service received the message.


        :return: The time_stamp of this PublishResult.
        :rtype: datetime
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """
        Sets the time_stamp of this PublishResult.
        The time that the service received the message.


        :param time_stamp: The time_stamp of this PublishResult.
        :type: datetime
        """
        self._time_stamp = time_stamp

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackupSummary(object):
    """
    A database backup.
    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the type property of a BackupSummary.
    #: This constant has a value of "INCREMENTAL"
    TYPE_INCREMENTAL = "INCREMENTAL"

    #: A constant which can be used with the type property of a BackupSummary.
    #: This constant has a value of "FULL"
    TYPE_FULL = "FULL"

    #: A constant which can be used with the type property of a BackupSummary.
    #: This constant has a value of "VIRTUAL_FULL"
    TYPE_VIRTUAL_FULL = "VIRTUAL_FULL"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a BackupSummary.
    #: This constant has a value of "RESTORING"
    LIFECYCLE_STATE_RESTORING = "RESTORING"

    #: A constant which can be used with the database_edition property of a BackupSummary.
    #: This constant has a value of "STANDARD_EDITION"
    DATABASE_EDITION_STANDARD_EDITION = "STANDARD_EDITION"

    #: A constant which can be used with the database_edition property of a BackupSummary.
    #: This constant has a value of "ENTERPRISE_EDITION"
    DATABASE_EDITION_ENTERPRISE_EDITION = "ENTERPRISE_EDITION"

    #: A constant which can be used with the database_edition property of a BackupSummary.
    #: This constant has a value of "ENTERPRISE_EDITION_HIGH_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = "ENTERPRISE_EDITION_HIGH_PERFORMANCE"

    #: A constant which can be used with the database_edition property of a BackupSummary.
    #: This constant has a value of "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new BackupSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BackupSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BackupSummary.
        :type compartment_id: str

        :param database_id:
            The value to assign to the database_id property of this BackupSummary.
        :type database_id: str

        :param display_name:
            The value to assign to the display_name property of this BackupSummary.
        :type display_name: str

        :param type:
            The value to assign to the type property of this BackupSummary.
            Allowed values for this property are: "INCREMENTAL", "FULL", "VIRTUAL_FULL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param time_started:
            The value to assign to the time_started property of this BackupSummary.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this BackupSummary.
        :type time_ended: datetime

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this BackupSummary.
        :type lifecycle_details: str

        :param availability_domain:
            The value to assign to the availability_domain property of this BackupSummary.
        :type availability_domain: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BackupSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "RESTORING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param database_edition:
            The value to assign to the database_edition property of this BackupSummary.
            Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_edition: str

        :param database_size_in_gbs:
            The value to assign to the database_size_in_gbs property of this BackupSummary.
        :type database_size_in_gbs: float

        :param shape:
            The value to assign to the shape property of this BackupSummary.
        :type shape: str

        :param version:
            The value to assign to the version property of this BackupSummary.
        :type version: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'database_id': 'str',
            'display_name': 'str',
            'type': 'str',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'lifecycle_details': 'str',
            'availability_domain': 'str',
            'lifecycle_state': 'str',
            'database_edition': 'str',
            'database_size_in_gbs': 'float',
            'shape': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'database_id': 'databaseId',
            'display_name': 'displayName',
            'type': 'type',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'lifecycle_details': 'lifecycleDetails',
            'availability_domain': 'availabilityDomain',
            'lifecycle_state': 'lifecycleState',
            'database_edition': 'databaseEdition',
            'database_size_in_gbs': 'databaseSizeInGBs',
            'shape': 'shape',
            'version': 'version'
        }

        self._id = None
        self._compartment_id = None
        self._database_id = None
        self._display_name = None
        self._type = None
        self._time_started = None
        self._time_ended = None
        self._lifecycle_details = None
        self._availability_domain = None
        self._lifecycle_state = None
        self._database_edition = None
        self._database_size_in_gbs = None
        self._shape = None
        self._version = None

    @property
    def id(self):
        """
        Gets the id of this BackupSummary.
        The `OCID`__ of the backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this BackupSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BackupSummary.
        The `OCID`__ of the backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this BackupSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this BackupSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this BackupSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BackupSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this BackupSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def database_id(self):
        """
        Gets the database_id of this BackupSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_id of this BackupSummary.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this BackupSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this BackupSummary.
        :type: str
        """
        self._database_id = database_id

    @property
    def display_name(self):
        """
        Gets the display_name of this BackupSummary.
        The user-friendly name for the backup. The name does not have to be unique.


        :return: The display_name of this BackupSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BackupSummary.
        The user-friendly name for the backup. The name does not have to be unique.


        :param display_name: The display_name of this BackupSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def type(self):
        """
        Gets the type of this BackupSummary.
        The type of backup.

        Allowed values for this property are: "INCREMENTAL", "FULL", "VIRTUAL_FULL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this BackupSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this BackupSummary.
        The type of backup.


        :param type: The type of this BackupSummary.
        :type: str
        """
        allowed_values = ["INCREMENTAL", "FULL", "VIRTUAL_FULL"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def time_started(self):
        """
        Gets the time_started of this BackupSummary.
        The date and time the backup started.


        :return: The time_started of this BackupSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this BackupSummary.
        The date and time the backup started.


        :param time_started: The time_started of this BackupSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this BackupSummary.
        The date and time the backup was completed.


        :return: The time_ended of this BackupSummary.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this BackupSummary.
        The date and time the backup was completed.


        :param time_ended: The time_ended of this BackupSummary.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this BackupSummary.
        Additional information about the current lifecycleState.


        :return: The lifecycle_details of this BackupSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this BackupSummary.
        Additional information about the current lifecycleState.


        :param lifecycle_details: The lifecycle_details of this BackupSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this BackupSummary.
        The name of the availability domain where the database backup is stored.


        :return: The availability_domain of this BackupSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this BackupSummary.
        The name of the availability domain where the database backup is stored.


        :param availability_domain: The availability_domain of this BackupSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this BackupSummary.
        The current state of the backup.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "RESTORING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BackupSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BackupSummary.
        The current state of the backup.


        :param lifecycle_state: The lifecycle_state of this BackupSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "RESTORING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def database_edition(self):
        """
        Gets the database_edition of this BackupSummary.
        The Oracle Database edition of the DB system from which the database backup was taken.

        Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_edition of this BackupSummary.
        :rtype: str
        """
        return self._database_edition

    @database_edition.setter
    def database_edition(self, database_edition):
        """
        Sets the database_edition of this BackupSummary.
        The Oracle Database edition of the DB system from which the database backup was taken.


        :param database_edition: The database_edition of this BackupSummary.
        :type: str
        """
        allowed_values = ["STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"]
        if not value_allowed_none_or_none_sentinel(database_edition, allowed_values):
            database_edition = 'UNKNOWN_ENUM_VALUE'
        self._database_edition = database_edition

    @property
    def database_size_in_gbs(self):
        """
        Gets the database_size_in_gbs of this BackupSummary.
        The size of the database in gigabytes at the time the backup was taken.


        :return: The database_size_in_gbs of this BackupSummary.
        :rtype: float
        """
        return self._database_size_in_gbs

    @database_size_in_gbs.setter
    def database_size_in_gbs(self, database_size_in_gbs):
        """
        Sets the database_size_in_gbs of this BackupSummary.
        The size of the database in gigabytes at the time the backup was taken.


        :param database_size_in_gbs: The database_size_in_gbs of this BackupSummary.
        :type: float
        """
        self._database_size_in_gbs = database_size_in_gbs

    @property
    def shape(self):
        """
        Gets the shape of this BackupSummary.
        Shape of the backup's source database.


        :return: The shape of this BackupSummary.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this BackupSummary.
        Shape of the backup's source database.


        :param shape: The shape of this BackupSummary.
        :type: str
        """
        self._shape = shape

    @property
    def version(self):
        """
        Gets the version of this BackupSummary.
        Version of the backup's source database


        :return: The version of this BackupSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this BackupSummary.
        Version of the backup's source database


        :param version: The version of this BackupSummary.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_instance_configuration_base import CreateInstanceConfigurationBase
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateInstanceConfigurationDetails(CreateInstanceConfigurationBase):
    """
    Details for creating an instance configuration by providing a list of configuration settings.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateInstanceConfigurationDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.CreateInstanceConfigurationDetails.source` attribute
        of this class is ``NONE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateInstanceConfigurationDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateInstanceConfigurationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateInstanceConfigurationDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateInstanceConfigurationDetails.
        :type freeform_tags: dict(str, str)

        :param source:
            The value to assign to the source property of this CreateInstanceConfigurationDetails.
            Allowed values for this property are: "NONE", "INSTANCE"
        :type source: str

        :param instance_details:
            The value to assign to the instance_details property of this CreateInstanceConfigurationDetails.
        :type instance_details: InstanceConfigurationInstanceDetails

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'source': 'str',
            'instance_details': 'InstanceConfigurationInstanceDetails'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'source': 'source',
            'instance_details': 'instanceDetails'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._source = None
        self._instance_details = None
        self._source = 'NONE'

    @property
    def instance_details(self):
        """
        **[Required]** Gets the instance_details of this CreateInstanceConfigurationDetails.

        :return: The instance_details of this CreateInstanceConfigurationDetails.
        :rtype: InstanceConfigurationInstanceDetails
        """
        return self._instance_details

    @instance_details.setter
    def instance_details(self, instance_details):
        """
        Sets the instance_details of this CreateInstanceConfigurationDetails.

        :param instance_details: The instance_details of this CreateInstanceConfigurationDetails.
        :type: InstanceConfigurationInstanceDetails
        """
        self._instance_details = instance_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OutOfBoxEntityTypeDetails(object):
    """
    A Single Entity Type Definition
    """

    #: A constant which can be used with the cloud_type property of a OutOfBoxEntityTypeDetails.
    #: This constant has a value of "CLOUD"
    CLOUD_TYPE_CLOUD = "CLOUD"

    #: A constant which can be used with the cloud_type property of a OutOfBoxEntityTypeDetails.
    #: This constant has a value of "NON_CLOUD"
    CLOUD_TYPE_NON_CLOUD = "NON_CLOUD"

    def __init__(self, **kwargs):
        """
        Initializes a new OutOfBoxEntityTypeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this OutOfBoxEntityTypeDetails.
        :type name: str

        :param internal_name:
            The value to assign to the internal_name property of this OutOfBoxEntityTypeDetails.
        :type internal_name: str

        :param category:
            The value to assign to the category property of this OutOfBoxEntityTypeDetails.
        :type category: str

        :param cloud_type:
            The value to assign to the cloud_type property of this OutOfBoxEntityTypeDetails.
            Allowed values for this property are: "CLOUD", "NON_CLOUD"
        :type cloud_type: str

        :param properties:
            The value to assign to the properties property of this OutOfBoxEntityTypeDetails.
        :type properties: list[EntityTypeProperty]

        """
        self.swagger_types = {
            'name': 'str',
            'internal_name': 'str',
            'category': 'str',
            'cloud_type': 'str',
            'properties': 'list[EntityTypeProperty]'
        }

        self.attribute_map = {
            'name': 'name',
            'internal_name': 'internalName',
            'category': 'category',
            'cloud_type': 'cloudType',
            'properties': 'properties'
        }

        self._name = None
        self._internal_name = None
        self._category = None
        self._cloud_type = None
        self._properties = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OutOfBoxEntityTypeDetails.
        Log analytics entity type name.


        :return: The name of this OutOfBoxEntityTypeDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OutOfBoxEntityTypeDetails.
        Log analytics entity type name.


        :param name: The name of this OutOfBoxEntityTypeDetails.
        :type: str
        """
        self._name = name

    @property
    def internal_name(self):
        """
        **[Required]** Gets the internal_name of this OutOfBoxEntityTypeDetails.
        Internal name for the log analytics entity type.


        :return: The internal_name of this OutOfBoxEntityTypeDetails.
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """
        Sets the internal_name of this OutOfBoxEntityTypeDetails.
        Internal name for the log analytics entity type.


        :param internal_name: The internal_name of this OutOfBoxEntityTypeDetails.
        :type: str
        """
        self._internal_name = internal_name

    @property
    def category(self):
        """
        **[Required]** Gets the category of this OutOfBoxEntityTypeDetails.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :return: The category of this OutOfBoxEntityTypeDetails.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this OutOfBoxEntityTypeDetails.
        Log analytics entity type category. Category will be used for grouping and filtering.


        :param category: The category of this OutOfBoxEntityTypeDetails.
        :type: str
        """
        self._category = category

    @property
    def cloud_type(self):
        """
        **[Required]** Gets the cloud_type of this OutOfBoxEntityTypeDetails.
        Log analytics entity type group. Supported values: ClOUD, NON_CLOUD.

        Allowed values for this property are: "CLOUD", "NON_CLOUD"


        :return: The cloud_type of this OutOfBoxEntityTypeDetails.
        :rtype: str
        """
        return self._cloud_type

    @cloud_type.setter
    def cloud_type(self, cloud_type):
        """
        Sets the cloud_type of this OutOfBoxEntityTypeDetails.
        Log analytics entity type group. Supported values: ClOUD, NON_CLOUD.


        :param cloud_type: The cloud_type of this OutOfBoxEntityTypeDetails.
        :type: str
        """
        allowed_values = ["CLOUD", "NON_CLOUD"]
        if not value_allowed_none_or_none_sentinel(cloud_type, allowed_values):
            raise ValueError(
                "Invalid value for `cloud_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._cloud_type = cloud_type

    @property
    def properties(self):
        """
        Gets the properties of this OutOfBoxEntityTypeDetails.
        A Single Entity Type Property Definition


        :return: The properties of this OutOfBoxEntityTypeDetails.
        :rtype: list[EntityTypeProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this OutOfBoxEntityTypeDetails.
        A Single Entity Type Property Definition


        :param properties: The properties of this OutOfBoxEntityTypeDetails.
        :type: list[EntityTypeProperty]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsMetaFunction(object):
    """
    LogAnalyticsMetaFunction
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsMetaFunction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param meta_function_argument:
            The value to assign to the meta_function_argument property of this LogAnalyticsMetaFunction.
        :type meta_function_argument: list[LogAnalyticsMetaFunctionArgument]

        :param component:
            The value to assign to the component property of this LogAnalyticsMetaFunction.
        :type component: str

        :param description:
            The value to assign to the description property of this LogAnalyticsMetaFunction.
        :type description: str

        :param edit_version:
            The value to assign to the edit_version property of this LogAnalyticsMetaFunction.
        :type edit_version: int

        :param meta_function_id:
            The value to assign to the meta_function_id property of this LogAnalyticsMetaFunction.
        :type meta_function_id: int

        :param java_class_name:
            The value to assign to the java_class_name property of this LogAnalyticsMetaFunction.
        :type java_class_name: str

        :param name:
            The value to assign to the name property of this LogAnalyticsMetaFunction.
        :type name: str

        """
        self.swagger_types = {
            'meta_function_argument': 'list[LogAnalyticsMetaFunctionArgument]',
            'component': 'str',
            'description': 'str',
            'edit_version': 'int',
            'meta_function_id': 'int',
            'java_class_name': 'str',
            'name': 'str'
        }

        self.attribute_map = {
            'meta_function_argument': 'metaFunctionArgument',
            'component': 'component',
            'description': 'description',
            'edit_version': 'editVersion',
            'meta_function_id': 'metaFunctionId',
            'java_class_name': 'javaClassName',
            'name': 'name'
        }

        self._meta_function_argument = None
        self._component = None
        self._description = None
        self._edit_version = None
        self._meta_function_id = None
        self._java_class_name = None
        self._name = None

    @property
    def meta_function_argument(self):
        """
        Gets the meta_function_argument of this LogAnalyticsMetaFunction.
        meta function argument object


        :return: The meta_function_argument of this LogAnalyticsMetaFunction.
        :rtype: list[LogAnalyticsMetaFunctionArgument]
        """
        return self._meta_function_argument

    @meta_function_argument.setter
    def meta_function_argument(self, meta_function_argument):
        """
        Sets the meta_function_argument of this LogAnalyticsMetaFunction.
        meta function argument object


        :param meta_function_argument: The meta_function_argument of this LogAnalyticsMetaFunction.
        :type: list[LogAnalyticsMetaFunctionArgument]
        """
        self._meta_function_argument = meta_function_argument

    @property
    def component(self):
        """
        Gets the component of this LogAnalyticsMetaFunction.
        component


        :return: The component of this LogAnalyticsMetaFunction.
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """
        Sets the component of this LogAnalyticsMetaFunction.
        component


        :param component: The component of this LogAnalyticsMetaFunction.
        :type: str
        """
        self._component = component

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsMetaFunction.
        description


        :return: The description of this LogAnalyticsMetaFunction.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsMetaFunction.
        description


        :param description: The description of this LogAnalyticsMetaFunction.
        :type: str
        """
        self._description = description

    @property
    def edit_version(self):
        """
        Gets the edit_version of this LogAnalyticsMetaFunction.
        edit version


        :return: The edit_version of this LogAnalyticsMetaFunction.
        :rtype: int
        """
        return self._edit_version

    @edit_version.setter
    def edit_version(self, edit_version):
        """
        Sets the edit_version of this LogAnalyticsMetaFunction.
        edit version


        :param edit_version: The edit_version of this LogAnalyticsMetaFunction.
        :type: int
        """
        self._edit_version = edit_version

    @property
    def meta_function_id(self):
        """
        Gets the meta_function_id of this LogAnalyticsMetaFunction.
        meta function Id


        :return: The meta_function_id of this LogAnalyticsMetaFunction.
        :rtype: int
        """
        return self._meta_function_id

    @meta_function_id.setter
    def meta_function_id(self, meta_function_id):
        """
        Sets the meta_function_id of this LogAnalyticsMetaFunction.
        meta function Id


        :param meta_function_id: The meta_function_id of this LogAnalyticsMetaFunction.
        :type: int
        """
        self._meta_function_id = meta_function_id

    @property
    def java_class_name(self):
        """
        Gets the java_class_name of this LogAnalyticsMetaFunction.
        java class name


        :return: The java_class_name of this LogAnalyticsMetaFunction.
        :rtype: str
        """
        return self._java_class_name

    @java_class_name.setter
    def java_class_name(self, java_class_name):
        """
        Sets the java_class_name of this LogAnalyticsMetaFunction.
        java class name


        :param java_class_name: The java_class_name of this LogAnalyticsMetaFunction.
        :type: str
        """
        self._java_class_name = java_class_name

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsMetaFunction.
        meta function name


        :return: The name of this LogAnalyticsMetaFunction.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsMetaFunction.
        meta function name


        :param name: The name of this LogAnalyticsMetaFunction.
        :type: str
        """
        self._name = name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
